@@ -15,7 +15,7 @@ class RequestType(Enum):
     GET_ACCESS_TOKEN = 'GET_ACCESS_TOKEN'
     DESCRIBE = 'DESCRIBE'
     READ = 'READ'
-    GET = 'GET'
+    GET_BY_ID = 'GET_BY_ID'
     CREATE = 'CREATE'
     UPDATE = 'UPDATE'
     DELETE = 'DELETE'
