@@ -28,7 +28,7 @@ class Synapse(ABC):
     def __set_request(self):
         if self.request_type == RequestType.DESCRIBE:
             return DescribeRequest.parse_obj(self.raw_request.body)
-        elif self.request_type in [RequestType.READ, RequestType.GET, RequestType.CREATE, RequestType.UPDATE, RequestType.DELETE]:
+        elif self.request_type in [RequestType.READ, RequestType.GET_BY_ID, RequestType.CREATE, RequestType.UPDATE, RequestType.DELETE]:
             return SyncRequest.parse_obj(self.raw_request.body)
         elif self.request_type in [RequestType.EXTRACT_WEBHOOK_IDENTIFIER, RequestType.PROCESS_WEBHOOK]:
             return WebhookRequest.parse_obj(self.raw_request.body)
@@ -66,8 +66,8 @@ class Synapse(ABC):
                 if not isinstance(response, ReadResponse):
                     raise self.__prep_invalid_response_exception(response)
 
-            elif self.request_type == RequestType.GET:
-                response = self.get()
+            elif self.request_type == RequestType.GET_BY_ID:
+                response = self.get_by_id()
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
@@ -182,7 +182,7 @@ class Synapse(ABC):
         pass
 
     @abstractmethod
-    def get(self):
+    def get_by_id(self):
         pass
 
     @abstractmethod
